@@ -4,7 +4,7 @@ use crossterm::{
     execute,
     terminal::{disable_raw_mode, enable_raw_mode, EnterAlternateScreen, LeaveAlternateScreen},
 };
-use gonk_core::{Bind, Database, Key, Modifier, Toml};
+use gonk_core::{sqlite, Bind, Database, Key, Modifier, Toml};
 use std::io::{stdout, Stdout};
 use std::time::Duration;
 use std::time::Instant;
@@ -154,7 +154,7 @@ impl App {
                                     self.queue.player.add_songs(songs);
                                 }
                                 Mode::Queue => {
-                                    if let Some(i) = self.queue.ui.index {
+                                    if let Some(i) = self.queue.ui.selection() {
                                         self.queue.player.play_song(i);
                                     }
                                 }
@@ -186,7 +186,7 @@ impl App {
                             }
                             _ if toml.hotkey.clear.contains(&bind) => self.queue.clear(),
                             _ if toml.hotkey.refresh_database.contains(&bind) => {
-                                self.db.reset();
+                                sqlite::reset();
                                 self.db.add_dirs(toml.paths());
                                 self.db.sync_database(toml.paths());
                             }
@@ -212,7 +212,7 @@ impl App {
                             _ if toml.hotkey.options.contains(&bind) => self.mode = Mode::Options,
                             _ if toml.hotkey.delete.contains(&bind) => {
                                 if let Mode::Queue = self.mode {
-                                    if let Some(i) = self.queue.ui.index {
+                                    if let Some(i) = self.queue.ui.selection() {
                                         self.queue.player.delete_song(i);
                                         //make sure the ui index is in sync
                                         let len = self.queue.player.songs.len().saturating_sub(1);
